@@ -2,7 +2,7 @@
 # -- kongodb --
 #-----------------------------
 
-from . import adapters, dictquery, lib, database, cursor, exceptions, types
+from . import adapters, dict_query, lib, database, exceptions
 
 # alias to Database
 kongodb = database.Database
